InputImage
==========

.. currentmodule:: toasty.pipeline

.. autoclass:: InputImage
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~InputImage.process_image

   .. rubric:: Methods Documentation

   .. automethod:: process_image
